# Release notes for MUSE v1.5.1 (August 27, 2025)

This release has some very small bug fixes and updates to documentation. See {github}`771`, {github}`782` and [a34081c](https://github.com/EnergySystemsModellingLab/MUSE_OS/commit/a34081cfb278a95f1acee7ba2beb43d9f1c53f3b)
